==> v0.01.zip: hugo/content/en/Imprint.md <==
---
title: "Imprint"
date: 2021-02-04T10:04:53+01:00
draft: false
---
[![German](/ger.png)](/de/Impressum)

This website is organized by FraLUG e.V.:

Frankfurter Linux User Group (FraLUG) e.V.   
c/o Jochen Schade   
Landgrafenring 14b   
63073 Offenbach   

Registered at the county court Frankfurt, association register: 14628

Represented through the steering committee:   
Jens Kühnel   
Jochen Schade   
Dr. Christoph Zimmermann   

<svg class="icon email"><use xlink:href="#email"></use></svg> info AT lugfrankfurt PUNKT de

If you have any problems, contact our web hoster [here](http://www.jekkt.com/impressum.php).

-----

## Disclosure of automated data storage and processing according to the General Data Protection Regulation (GDPR)

### Provision of our statutory and business services

We process the data of our members, supporters, prospects, customers or other persons in accordance with Art. 6 para. 1 lit. b. GDPR, if we offer them contractual services or in the context of an existing business relationship, e.g. members, or are themselves recipients of benefits and benefits. Incidentally, we process the data of affected persons in accordance with. Art. 6 para. 1 lit. f. GDPR based on our legitimate interests, e.g. when it comes to administrative tasks or public relations.

The data processed, the nature, scope and purpose and necessity of their processing are determined by the underlying contractual relationship. This includes in principle inventory and master data of the persons (e.g., name, address, etc.) as well as the contact data (e.g., e-mail address, telephone, etc.).

We delete data that is no longer required to serve our statutory and business purposes. This is determined according to the respective tasks and contractual relationships. In the case of business processing, we retain the data for as long as they may be relevant to the transaction, as well as with regard to any warranty or liability obligations. The necessity of keeping the data is checked every three years; otherwise the statutory storage obligations apply.

### Hosting and e-mailing

The hosting services we use are designed to provide the following services: infrastructure and platform services, computing capacity, storage and database services, e-mailing, security and technical maintenance services we use to operate this online service.

Here we, or our hosting provider, process inventory data, contact data, content data, contract data, usage data, meta and communication data of customers, interested parties and visitors to this online offer on the basis of our legitimate interests in an efficient and secure provision of this online offer acc. Art. 6 para. 1 lit. f GDPR i.V.m. Art. 28 GDPR (conclusion of contract processing contract).

### Registration

Users can create a user account. As part of the registration, the required mandatory information is communicated to the users and based on Art. 6 para. 1 lit. b GDPR processed for purposes of providing the user account. The processed data include in particular the login information (name, password and an e-mail address). The data entered during registration will be used for the purpose of using the user account and its purpose.

Users may have access to information relevant to their user account, e.g. technical changes, be informed by e-mail. If users have terminated their user account, their data will be deleted with respect to the user account, subject to a statutory retention requirement. It is the responsibility of the users to secure their data upon termination before the end of the contract. We are entitled to irretrievably delete all user data stored during the term of the contract.

As part of the use of our registration and registration functions as well as the use of the user account, the IP address and the time of the respective user action will be saved. The storage is based on our legitimate interests, as well as the user's protection against misuse and other unauthorized use. A transfer of these data to third parties does not take place, unless it is necessary for the prosecution of our claims or there is a legal obligation in accordance with. Art. 6 para. 1 lit. c GDPR.

==> v0.03.zip: hugo/content/en/Imprint.md <==
---
title: "Imprint"
date: 2021-02-04T10:04:53+01:00
draft: false
---
[![German](/ger.png#floatright)](/de/Impressum)

This website is organized by FraLUG e.V.:

Frankfurter Linux User Group (FraLUG) e.V.   
c/o Jochen Schade   
Landgrafenring 14b   
63073 Offenbach   

Registered at the county court Frankfurt, association register: 14628

Represented through the steering committee:   
Jens Kühnel   
Jochen Schade   
Dr. Christoph Zimmermann   

<svg class="icon email"><use xlink:href="#email"></use></svg> info AT lugfrankfurt PUNKT de

If you have any problems, contact our web hoster [here](http://www.jekkt.com/impressum.php).

-----

## Disclosure of automated data storage and processing according to the General Data Protection Regulation (GDPR)

### Provision of our statutory and business services

We process the data of our members, supporters, prospects, customers or other persons in accordance with Art. 6 para. 1 lit. b. GDPR, if we offer them contractual services or in the context of an existing business relationship, e.g. members, or are themselves recipients of benefits and benefits. Incidentally, we process the data of affected persons in accordance with. Art. 6 para. 1 lit. f. GDPR based on our legitimate interests, e.g. when it comes to administrative tasks or public relations.

The data processed, the nature, scope and purpose and necessity of their processing are determined by the underlying contractual relationship. This includes in principle inventory and master data of the persons (e.g., name, address, etc.) as well as the contact data (e.g., e-mail address, telephone, etc.).

We delete data that is no longer required to serve our statutory and business purposes. This is determined according to the respective tasks and contractual relationships. In the case of business processing, we retain the data for as long as they may be relevant to the transaction, as well as with regard to any warranty or liability obligations. The necessity of keeping the data is checked every three years; otherwise the statutory storage obligations apply.

### Hosting and e-mailing

The hosting services we use are designed to provide the following services: infrastructure and platform services, computing capacity, storage and database services, e-mailing, security and technical maintenance services we use to operate this online service.

Here we, or our hosting provider, process inventory data, contact data, content data, contract data, usage data, meta and communication data of customers, interested parties and visitors to this online offer on the basis of our legitimate interests in an efficient and secure provision of this online offer acc. Art. 6 para. 1 lit. f GDPR i.V.m. Art. 28 GDPR (conclusion of contract processing contract).

### Registration

Users can create a user account. As part of the registration, the required mandatory information is communicated to the users and based on Art. 6 para. 1 lit. b GDPR processed for purposes of providing the user account. The processed data include in particular the login information (name, password and an e-mail address). The data entered during registration will be used for the purpose of using the user account and its purpose.

Users may have access to information relevant to their user account, e.g. technical changes, be informed by e-mail. If users have terminated their user account, their data will be deleted with respect to the user account, subject to a statutory retention requirement. It is the responsibility of the users to secure their data upon termination before the end of the contract. We are entitled to irretrievably delete all user data stored during the term of the contract.

As part of the use of our registration and registration functions as well as the use of the user account, the IP address and the time of the respective user action will be saved. The storage is based on our legitimate interests, as well as the user's protection against misuse and other unauthorized use. A transfer of these data to third parties does not take place, unless it is necessary for the prosecution of our claims or there is a legal obligation in accordance with. Art. 6 para. 1 lit. c GDPR.
